pub struct SDE { /* private fields */ }Expand description
Stochastic Differential Equation solver for pharmacometric models.
This struct represents a stochastic differential equation system and provides methods to simulate particles and estimate likelihood for PKPD modeling.
SDE models introduce stochasticity into the system dynamics, allowing for more realistic modeling of biological variability and uncertainty.
Implementations
Sourceimpl SDE
impl SDE
Sourcepub fn new(
drift: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &mut NalgebraVec<f64>, &NalgebraVec<f64>, &Covariates),
diffusion: fn(&NalgebraVec<f64>, &mut NalgebraVec<f64>),
lag: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>,
fa: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>,
init: fn(&NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>),
out: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>),
nparticles: usize,
) -> SDE
pub fn new( drift: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &mut NalgebraVec<f64>, &NalgebraVec<f64>, &Covariates), diffusion: fn(&NalgebraVec<f64>, &mut NalgebraVec<f64>), lag: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>, fa: fn(&NalgebraVec<f64>, f64, &Covariates) -> HashMap<usize, f64>, init: fn(&NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>), out: fn(&NalgebraVec<f64>, &NalgebraVec<f64>, f64, &Covariates, &mut NalgebraVec<f64>), nparticles: usize, ) -> SDE
Creates a new stochastic differential equation solver with default Neqs.
Use builder methods to configure dimensions:
SDE::new(drift, diffusion, lag, fa, init, out, nparticles)
.with_nstates(2)
.with_ndrugs(1)
.with_nout(1)Sourcepub fn with_nstates(self, nstates: usize) -> SDE
pub fn with_nstates(self, nstates: usize) -> SDE
Set the number of state variables.
Sourcepub fn with_ndrugs(self, ndrugs: usize) -> SDE
pub fn with_ndrugs(self, ndrugs: usize) -> SDE
Set the number of drug input channels (size of bolus[] and rateiv[]).